@@ -31,7 +31,7 @@
     cl <- match.call()
     if(!is.matrix(x) && !is.data.frame(x)) stop('Data must either be a data frame or a matrix')
     if(!inherits(x[1], "data.frame")) x <- fix.dplyr(x)    #to get around a problem created by dplyr
-    if(!is.null(keys)){# 3 cases  1 it is a list, 2 is a vector of character, 3 it is keys matrix  4 it is a list of items to  reverse
+    if(!is.null(keys)){# 4 cases  1 it is a list, 2 is a vector of character, 3 it is keys matrix  4 it is a list of items to  reverse
     if( is.list(keys)) { select <- sub("-","",unlist(keys))   #added 9/26/16 to speed up scoring one scale from many
       	x <- x[,select] 
       	keys <- make.keys(x,keys)} else {if(!is.numeric(keys)){
@@ -40,7 +40,7 @@
       	keys <- temp
       }}
       }
-      
+    if(missing(impute) | (!is.null(impute) && (impute =="none"))) impute <- NULL  
     nvar <- dim(x)[2]
     nsub <- dim(x)[1]
     scores <- NULL
@@ -50,9 +50,9 @@
       raw <- TRUE
        if(!is.null(impute) ) {
        		if(impute=="median") {item.impute <- apply(x,2,median,na.rm=na.rm)} else {item.impute <- apply(x,2,mean,na.rm=na.rm) } #column values
-  #     		apply(x,1,function(x) { x[is.na(x)]  <- item.impute[]}) }  #replace row wise
-                 
-            for(i in 1:nsub) {for (j in 1:nvar) {x[i,is.na(x[i,j])] <- item.impute[j] }   }  
+ 
+            find.na <- which(is.na(x),arr.ind=TRUE)
+            if(NROW(find.na) >0) x[find.na] <- item.impute[find.na[,2]]   #added 08/28/20 to fix a problem where we putting in imputed values for all the variables
             }
        item.var <- apply(x,2,sd,na.rm=na.rm)
        bad <- which((item.var <= 0)|is.na(item.var))
@@ -232,7 +232,9 @@
        	         boot.ci <- NULL}
        	names(Unidim) <- "Unidim"
        	names(Fit.off) <- "Fit.off" 
-        result <- list(total=alpha.total,alpha.drop=by.item,item.stats=stats,response.freq=response.freq,keys=keys,scores = total,nvar=nvar,boot.ci=boot.ci,boot=boot,Unidim=Unidim,var.r=var.r,Fit=Fit.off,call=cl,title=title)
+       	feldt <- alpha.ci(alpha.total[1],nsub,nvar)
+       	keys <- keys2list(as.matrix(keys))
+        result <- list(total=alpha.total,alpha.drop=by.item,item.stats=stats,response.freq=response.freq,keys=keys,scores = total,nvar=nvar,boot.ci=boot.ci,boot=boot,feldt=feldt,Unidim=Unidim,var.r=var.r,Fit=Fit.off,call=cl,title=title)
         class(result) <- c("psych","alpha")
         return(result) 
     }
@@ -242,6 +244,7 @@
   #January 30, 2011  - added the max category parameter (max)
   #June 20, 2011 -- revised to add the check.keys option as suggested by Jeremy Miles
   #Oct 3, 2013 check for variables with no variance and drop them with a warning
+  #May 27, 2022 convert the keys output to a named list so that we can use if in other functions
   #November 22, 2013  Added the standard error as suggested by 
   #modified December 6, 2013 to add empirical confidence estimates
   #modified January 9, 2014 to add multicore capabilities to the bootstrap 
@@ -269,12 +272,19 @@ invisible(object)
 #apply the Duhacheck and Iacobucci estimates
 #compare with Feldt's estimate
 "alpha.ci" <- function(alpha,n.obs,n.var=NULL,p.val=.05,digits=2) {
-#  Q = (2 * n^2/((n - 1)^2 * (sum(C)^3))) * (sum(C) * (tr(C%*%C) +  (tr(C))^2) - 2 * (tr(C) * sum(C%*%C)))   #correction from Tamaki Hattori
- CI.high <- 1- (1-alpha)* qf(p.val/2,n.obs-1,Inf)
- CI.low <- 1-  (1-alpha)* qf(1-p.val/2,n.obs-1,Inf)
+# Q = (2 * n^2/((n - 1)^2 * (sum(C)^3))) * (sum(C) * (tr(C%*%C) +  (tr(C))^2) - 2 * (tr(C) * sum(C%*%C)))   #correction from Tamaki Hattori
+ CI.high <- 1- (1-alpha)* qf(p.val/2,df1=n.obs-1,df2=(n.obs-1)*(n.var-1))
+ CI.low <- 1-  (1-alpha)* qf(1-p.val/2,df1=n.obs-1,df2=(n.obs-1)*(n.var-1))  #Inf changed inf to nvar -1  3/3/22
+#CI.high <- 1- (1-alpha)* qf(p.val/2,df1=n.obs-1,df2=Inf)
+#CI.low <- 1-  (1-alpha)* qf(1-p.val/2,df1=n.obs-1,df2=Inf)
 if(!is.null(n.var)) {r.bar <- alpha/(n.var - alpha*(n.var-1)) } else {r.bar=NA}
 result <- list(lower.ci =CI.low,alpha=alpha,upper.ci=CI.high,r.bar=r.bar)
-print(result,digits=digits)
+#print(result,digits=digits)
+class(result) <- c("psych","alpha.ci")
 invisible(result)
 }
 
+#convert alpha the the average r
+alpha2r <- function(alpha,n.var) {
+   r.bar <- alpha/(n.var - alpha*(n.var-1))
+  r.bar}
\ No newline at end of file
