@@ -1,8 +1,10 @@
 "error.bars.by" <-
-function (x,group,data=NULL,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= NULL, 
-xlim=NULL, eyes=TRUE,alpha=.05,sd=FALSE,labels=NULL, v.labels=NULL,v2.labels=NULL,add.labels=NULL,
- pos=NULL,arrow.len=.05,min.size=1, add=FALSE,bars=FALSE,within=FALSE,colors=c("black","blue","red"),
- lty,lines=TRUE, legend=0,pch=16,density=-10,stats=NULL,...)  # x   data frame with 
+function (x,group,data=NULL,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,
+	ylim= NULL, xlim=NULL, eyes=TRUE,alpha=.05,sd=FALSE,labels=NULL, 
+	v.labels=NULL,v2.labels=NULL,add.labels=NULL,
+ 	pos=NULL,arrow.len=.05,min.size=1, add=FALSE,bars=FALSE, within=FALSE,
+ 	colors=c("black","blue","red"),lty,lines=TRUE, legend=0, pch=16,
+ 	density=-10,stats=NULL,...)  # x   data frame with 
     {
 
     if(!lines) {typ <- "p"} else {typ <- "b"}
@@ -114,9 +116,11 @@ n.pch =length(pch)
             for(i in 1:n.var) {
              for (j in 1:n.group) {
          	 xcen <- group.means[i,j]
-    	 	 xse  <- group.se[i,j]
+    	 	 
+    	 	xse  <- group.se[i,j]
+    	 	xn <- group.n[i,j]
     	 	if(sd) {ci <- 1} else {ci <- qt(1-alpha/2,group.n[i,j])}
-        if(is.finite(xse) && xse>0)     arrows(mp[i,j],xcen-ci*xse,mp[i,j],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
+        if(is.finite(xse) && xse>0 && xn > 0  && is.finite(ci))     arrows(mp[i,j],xcen-ci*xse,mp[i,j],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
           }} }
          
          
@@ -246,10 +250,10 @@ n.pch =length(pch)
     		  #now, draw the points with different line types and colors for each value of the second grouping variable
     		 #we want to adjust the line type for the fact that we have two different grouping variables 
     		
-    		  points(x.values,var.means[i,1:(n.grp1)],typ = typ,lty=lty[((i-1) %% 8 +1)],col = colors[(i) %% n.color + 1], pch=pch[i],...) 
+    		  points(x.values,var.means[i,1:(n.grp1)],typ = typ,lty=lty[((i-1) %% 8 +1)],col = colors[(i-1) %% n.color + 1], pch=pch[i],...) 
    if(n.grp2>1)  {		  
      for(grp2 in 1:(n.grp2-1)){
-    		    points(x.values,var.means[i,(n.grp1 *grp2 +1):(n.grp1*(grp2+1))],typ=typ,lty=lty[(grp2) %% 8 +1],col = colors[grp2 %% n.color + 1], pch=pch[(grp2 %% n.pch + 1)],...)
+    		    points(x.values,var.means[i,(n.grp1 *grp2 +1):(n.grp1*(grp2+1))],typ=typ,lty=lty[(grp2-1) %% 8 +1],col = colors[(grp2-1) %% n.color + 1], pch=pch[((grp2-1) %% n.pch + 1)],...)
     		# if(n.grp1 < n.group) { points(x.values1,var.means[i,(n.grp1 +1):(n.group)],typ = typ,lty=lty[((1:(n.grp1)-1) %% 8 +1)],col = colors[(1:(n.grp1)) %% n.color + 1], pch=pch[i],...) }
     		   }     # points(x.values,var.means[i,],typ = typ,lty=lty,...)
     		}
@@ -291,8 +295,13 @@ n.pch =length(pch)
    	if(n.grp1 < n.group) {
    		  for (g in 1: n.grp1) {
    		 
-   		    for(grp2 in 1:(n.grp2-1)){
-    	              if(x.cat)  {arrows(g,xcen[g+n.grp1*grp2]-ci[g+n.grp1*grp2]*xse[g+n.grp1*grp2],g,xcen[g+n.grp1*grp2]+ci[g+n.grp1*grp2]* xse[g+n.grp1*grp2],length=arrow.len, angle = 90, code=3, col = colors[(grp2) %% n.color +1], lty=(lty[((grp2-1) %% 8 +1)]), lwd = par("lwd"), xpd = NULL)
+   		    for(grp2 in 1:(n.grp2-1)){if(!is.na(xse[g + n.grp1]) && (xse[g + n.grp1] > 0) && (ci[g + n.grp1]>0 )) {
+   		    
+   		   
+   		    
+   		    
+    	              if(x.cat)  {
+    	              arrows(g,xcen[g+n.grp1*grp2]-ci[g+n.grp1*grp2]*xse[g+n.grp1*grp2],g,xcen[g+n.grp1*grp2]+ci[g+n.grp1*grp2]* xse[g+n.grp1*grp2],length=arrow.len, angle = 90, code=3, col = colors[(grp2) %% n.color +1], lty=(lty[((grp2-1) %% 8 +1)]), lwd = par("lwd"), xpd = NULL)
     	                   } else {#consider the none cat condition 
     			                  x.values <- as.numeric(x.values)
     			                  arrows(x.values[g],xcen[g+n.grp1*grp2]-ci[g+n.grp1*grp2]*xse[g+n.grp1*grp2],x.values[g],xcen[g+n.grp1*grp2]+ci[g+n.grp1*grp2]* xse[g+n.grp1*grp2],length=arrow.len, angle = 90, code=3, col = colors[(grp2) %% n.color +1], lty=(lty[((grp2-1) %% 8 +1)]), lwd = par("lwd"), xpd = NULL)
@@ -307,8 +316,8 @@ n.pch =length(pch)
     	            if (eyes) {catseyes(x.values[g],xcen[g+n.grp1],xse[g+n.grp1],x.stats$n[g+n.grp1],alpha=alpha,density=density[(i-1) %% n.color +1],col=colors[(i-1) %% n.color +1] )}} 
     	}
     	}
-    	}
- 
+    	}  #for grp2 loop
+   }
      }
      if(x.cat) {axis(1,1:n.grp1,v.labels,...) } else {axis(1)}
     		axis(2,...)
@@ -317,16 +326,19 @@ n.pch =length(pch)
     
     #### now add labels and lengeds if desirec		
       if(!is.null(add.labels)) {
-
         
                if(is.null(v2.labels)) v2.labels <- names(unlist(dimnames(group.stats)[2]))
         if(is.null(pos)) {
-        if(x.cat){text.values <- data.frame(x=rep((.5+ (add.labels == "right")* n.grp1),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1-1),n.grp2 * n.grp1,(n.grp1))],name=v2.labels)} else {
-                   text.values <- data.frame(x=rep((.5+ (add.labels == "right") * x.values[n.grp1]),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1-1),n.grp2 * n.grp1,(n.grp1))],name=v2.labels)}
+
+        if(x.cat) {text.values <- data.frame(x=rep(.5 + (add.labels=="right")*NCOL(var.means),NROW(var.means)),y=var.means[,(add.labels=="right")*(NCOL(var.means)-1)+1],name=v2.labels)} else {
+                   text.values <- data.frame(x=rep((.5+ (add.labels == "right") * x.values[n.grp1]),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1),n.grp2 * n.grp1,(n.grp1))],name=v2.labels)}
+        #if(x.cat){text.values <- data.frame(x=rep((.5+ (add.labels == "right")* n.grp1),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1-1),n.grp2 * n.grp1,)],name=v2.labels)} else {
+                  # text.values <- data.frame(x=rep((.5+ (add.labels == "right") * x.values[n.grp1]),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1),n.grp2 * n.grp1,(n.grp1))],name=v2.labels)}
                    
                    text(text.values$x,text.values$y,text.values$name)
         } else {
-            text.values <- data.frame(x=rep((.5+ (add.labels == "right")* x.values[n.grp1]),n.grp2),y=var.means[seq(1+(add.labels == "right")* (n.grp1-1),n.grp2 * n.grp1,(n.grp1))],name=v2.labels,position=pos)
+            text.values <- data.frame(x=rep(.5 + (add.labels=="right")*NCOL(var.means)),y=var.means[,NCOL(var.means)],name=v2.labels ,position=pos)
+           # text.values <- data.frame(x=rep((.5+ (add.labels == "right")* x.values[n.grp1]),n.grp2),y=var.means[,1+(add.labels == "right")* (n.grp1-1) ],name=v2.labels,position=pos)
         text(text.values$x,text.values$y,text.values$name,pos=text.values$position)
                }
 
