@@ -5,7 +5,6 @@
 # "sim.hierarchical" <-
 # function (gload=NULL,fload=NULL,n=0,raw=FALSE,mu = NULL) {
 # cl <- match.call()
-# require(MASS)
 #  if(is.null(gload)) gload=matrix(c(.9,.8,.7),nrow=3)
 #  if(is.null(fload)) {fload <-matrix(c(.8,.7,.6,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)}
 # 
@@ -63,9 +62,10 @@ for(i in (nvar+1):NROW(f)) {
 # A function to create a correlation matrix with a hierarchical structure
 # The default values match those of Jensen and Weng
 #completely rewritten, March 15, 2021 to add in the ability to report factor sccores
+#modified May 16 to be able to return "items" rather than continuous scales
 
 "sim.hierarchical" <-
-function (gload=NULL,fload=NULL,n=0, raw=TRUE, mu = NULL) {
+function (gload=NULL,fload=NULL,n=0, raw=TRUE, mu = NULL,categorical=FALSE, low=-3,high=3,threshold=NULL) {
 
 cl <- match.call()
 #first, prepare the jensen defaults
@@ -92,6 +92,7 @@ cl <- match.call()
      nvar <- nrow(fload)
     colnames(model) <- rownames(model)<- paste0("V",1:nvar) 
     n.groups <- NCOL(gfstar )
+    if(!is.null(threshold)) {if (length(threshold) < nvar) threshold <- sample(threshold, nvar, replace=TRUE)}
     
   if(n>0) { #make up the data
     
@@ -105,6 +106,17 @@ cl <- match.call()
      theta <- t(gfstar %*% t(g))  #g are the orthogonal factor scores, theta are the noise free observed
      error <- matrix(rnorm(n*nvar),ncol=nvar)
      observed <-  theta + error %*% (U)  #weight the error by uniqueness of the variables
+     
+     if(categorical) {#convert from continuous to categorical
+         if(is.null(threshold)) {
+    	observed = round(observed)       #round all items to nearest integer value
+		observed[(observed <= low)] <- low     
+		observed[(observed > high) ] <- high 
+		} else {
+		 i <- 1:nvar
+		  observed <- t(t(observed [,i]) > threshold[i]) + 0 }  
+		}
+
      colnames(observed) <- paste0("V",1:nvar)
     
   	 r <- cor(observed)
